# QUBOgen [![Build Status](https://travis-ci.org/tamuhey/qubogen.svg?branch=master)](https://travis-ci.org/tamuhey/qubogen)

- QUBO matrix generator on major combinatorial optimization problems written in Python

# Installation

```bash
$ git clone https://github.com/tamuhey/qubogen
$ cd qubogen
$ pip install -e .
```

# Usage

- See [Number Partitioning example in JupyterNotebook](./notebooks/number_partitioning.ipynb)

# Refs

- [A Tutorial on Formulating and Using QUBO Models](https://arxiv.org/abs/1811.11538)
